PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/AStar.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Macros
AStar.hpp File Reference
`#include "Log.hpp"`
`#include "PCBoard.hpp"`
`#include "NavGrid.hpp"`
`#include "Path.hpp"`
`#include <queue>`

Go to the source code of this file.

## Data Structures
class | NavPointRef
class | AStar

## Macros
#define | ASTAR_ALLOW_XOVER false
| Whether we can route diagonally if the adjacent directions (U,L for UL etc.) are blocked.
#define | PERF_COUNTER_T(i)
#define | PERF_COUNTER_D(a, b)

## Macro Definition Documentation

## ◆ ASTAR_ALLOW_XOVER

#define ASTAR_ALLOW_XOVER false

Whether we can route diagonally if the adjacent directions (U,L for UL etc.) are blocked.

## ◆ PERF_COUNTER_D

#define PERF_COUNTER_D | ( |  | a,
|  |  | b )

Value:
std::chrono::duration_cast<std::chrono::nanoseconds>(__t##b - __t##a).count()

## ◆ PERF_COUNTER_T

#define PERF_COUNTER_T | ( |  | i | ) |

Value:
auto __t##i = std::chrono::high_resolution_clock::now()